==> racer-0.1.1.tgz: package/lib/mixin.ot/Field.server.js <==
var Field, FieldConnection, syncqueue, text;
var __bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; };
text = require('share/lib/types/text');
syncqueue = require('share/lib/server/syncqueue');
FieldConnection = require('./FieldConnection.server');
Field = module.exports = function(adapter, pubSub, path, version, type) {
  this.version = version;
  this.type = type != null ? type : text;
  this.adapter = adapter;
  this.path = path;
  this.snapshot = '';
  this.meta = {};
  this.ops = [];
  this.connections = {};
  this.applyQueue = syncqueue(__bind(function(_arg, callback) {
    var newDocData, newOpData, op, opMeta, opVersion, ops, realOp, _i, _len;
    op = _arg.op, opVersion = _arg.v, opMeta = _arg.meta;
    opMeta || (opMeta = {});
    opMeta.ts = Date.now();
    if (opVersion > this.version) {
      return callback(new Error('Op at future version'));
    }
    if (opVersion < this.version) {
      ops = this.getOps(opVersion);
      try {
        for (_i = 0, _len = ops.length; _i < _len; _i++) {
          realOp = ops[_i];
          op = this.type.transform(op, realOp.op, 'left');
          opVersion++;
        }
      } catch (err) {
        return callback(err);
      }
    }
    try {
      this.snapshot = this.type.apply(this.snapshot, op);
      this.version++;
    } catch (err) {
      return callback(err);
    }
    newOpData = {
      path: this.path,
      op: op,
      meta: opMeta,
      v: opVersion
    };
    newDocData = {
      snapshot: this.snapshot,
      type: this.type.name,
      v: opVersion + 1,
      meta: this.meta
    };
    this.ops.push({
      op: op,
      v: opVersion,
      meta: opMeta
    });
    pubSub.publish(this.path, {
      ot: newOpData
    });
    return callback(null, opVersion);
  }, this));
};
Field.prototype = {
  getSnapshot: function(callback) {
    var otPath;
    otPath = 'OT.' + this.path;
    return this.adapter.get(otPath, function(err, val, ver) {
      if (val === void 0) {
        return this.adapter.set(otPath, val, {
          ot: true
        }, function(err, val) {});
      }
    });
  },
  applyOp: function(opData, callback) {
    return process.nextTick(__bind(function() {
      return this.applyQueue(opData, callback);
    }, this));
  },
  registerSocket: function(socket, ver) {
    var client;
    client = new FieldConnection(this, socket);
    if (ver != null) {
      client.listenSinceVer(ver != null ? ver : null);
    }
    this.connections[socket.id] = client;
    return client;
  },
  unregisterSocket: function(socket) {
    return delete this.connections[socket.id];
  },
  client: function(socketId) {
    return this.connections[socketId];
  },
  getOps: function(start, end) {
    if (end == null) {
      end = this.version;
    }
    return this.ops.slice(start, end);
  },
  toJSON: function() {
    return {
      version: this.version,
      path: this.path,
      snapshot: this.snapshot,
      meta: this.meta,
      ops: this.ops
    };
  }
};

==> racer-0.1.3.tgz: package/lib/mixin.ot/Field.server.js <==
var Field, FieldConnection, syncqueue, text;

text = require('share/lib/types/text');

syncqueue = require('share/lib/server/syncqueue');

FieldConnection = require('./FieldConnection.server');

Field = module.exports = function(adapter, pubSub, path, version, type) {
  var _this = this;
  this.version = version;
  this.type = type != null ? type : text;
  this.adapter = adapter;
  this.path = path;
  this.snapshot = '';
  this.meta = {};
  this.ops = [];
  this.connections = {};
  this.applyQueue = syncqueue(function(_arg, callback) {
    var newDocData, newOpData, op, opMeta, opVersion, ops, realOp, _i, _len;
    op = _arg.op, opVersion = _arg.v, opMeta = _arg.meta;
    opMeta || (opMeta = {});
    opMeta.ts = Date.now();
    if (opVersion > _this.version) {
      return callback(new Error('Op at future version'));
    }
    if (opVersion < _this.version) {
      ops = _this.getOps(opVersion);
      try {
        for (_i = 0, _len = ops.length; _i < _len; _i++) {
          realOp = ops[_i];
          op = _this.type.transform(op, realOp.op, 'left');
          opVersion++;
        }
      } catch (err) {
        return callback(err);
      }
    }
    try {
      _this.snapshot = _this.type.apply(_this.snapshot, op);
      _this.version++;
    } catch (err) {
      return callback(err);
    }
    newOpData = {
      path: _this.path,
      op: op,
      meta: opMeta,
      v: opVersion
    };
    newDocData = {
      snapshot: _this.snapshot,
      type: _this.type.name,
      v: opVersion + 1,
      meta: _this.meta
    };
    _this.ops.push({
      op: op,
      v: opVersion,
      meta: opMeta
    });
    pubSub.publish(_this.path, {
      ot: newOpData
    });
    return callback(null, opVersion);
  });
};

Field.prototype = {
  getSnapshot: function(callback) {
    var otPath;
    otPath = 'OT.' + this.path;
    return this.adapter.get(otPath, function(err, val, ver) {
      if (val === void 0) {
        return this.adapter.set(otPath, val, {
          ot: true
        }, function(err, val) {});
      }
    });
  },
  applyOp: function(opData, callback) {
    var _this = this;
    return process.nextTick(function() {
      return _this.applyQueue(opData, callback);
    });
  },
  registerSocket: function(socket, ver) {
    var client;
    client = new FieldConnection(this, socket);
    if (ver != null) client.listenSinceVer(ver != null ? ver : null);
    this.connections[socket.id] = client;
    return client;
  },
  unregisterSocket: function(socket) {
    return delete this.connections[socket.id];
  },
  client: function(socketId) {
    return this.connections[socketId];
  },
  getOps: function(start, end) {
    if (end == null) end = this.version;
    return this.ops.slice(start, end);
  },
  toJSON: function() {
    return {
      version: this.version,
      path: this.path,
      snapshot: this.snapshot,
      meta: this.meta,
      ops: this.ops
    };
  }
};
